@@ -1,4 +1,4 @@
-#! /bin/sh
+#!/bin/sh
 #
 # Tell them not to be alarmed.
 
@@ -10,10 +10,9 @@ failures=0
 cat <<\EOF
 
 Please, do not be alarmed if some of the tests failed.
-Report them to <bug-gnu-utils@gnu.org>,
+Report them to <bug-grep@gnu.org>,
 with the line number, the name of the file,
 and grep version number 'grep --version'.
-Make sure you have the word grep in the subject.
 Thank You.
 
 EOF
